@@ -33,10 +33,7 @@ class Verifier:
 
         for i in range(len(calls)):
             calls_subset = calls[i : i + len(rehearsals)]
-            matches = [
-                match_event(c, r)
-                for c, r in zip(calls_subset, rehearsals)  # noqa: B905
-            ]
+            matches = [match_event(c, r) for c, r in zip(calls_subset, rehearsals)]
 
             if all(matches) and len(calls_subset) == len(rehearsals):
                 match_count = match_count + 1
