@@ -2,12 +2,12 @@
 
 See the [warnings guide][] for more details.
 
-[warnings guide]: ../usage/errors-and-warnings/#warnings
+[warnings guide]: usage/errors-and-warnings.md#warnings
 """
 import os
 from typing import Sequence
 
-from .spy_events import SpyEvent, WhenRehearsal, VerifyRehearsal
+from .spy_events import SpyEvent, SpyRehearsal, VerifyRehearsal
 from .stringify import stringify_call, stringify_error_message, count
 
 
@@ -25,21 +25,21 @@ class MiscalledStubWarning(DecoyWarning):
     - Configured as a stub with [`when`][decoy.Decoy.when]
     - Called with arguments that do not match any configured behaviors
 
-    See the [MiscalledStubWarning guide] for more details.
+    See the [MiscalledStubWarning guide][] for more details.
 
-    [MiscalledStubWarning guide]: ../usage/errors-and-warnings/#miscalledstubwarning
+    [MiscalledStubWarning guide]: usage/errors-and-warnings.md#miscalledstubwarning
 
     Attributes:
         rehearsals: The mocks's configured rehearsals.
         calls: Actual calls to the mock.
     """
 
-    rehearsals: Sequence[WhenRehearsal]
+    rehearsals: Sequence[SpyRehearsal]
     calls: Sequence[SpyEvent]
 
     def __init__(
         self,
-        rehearsals: Sequence[WhenRehearsal],
+        rehearsals: Sequence[SpyRehearsal],
         calls: Sequence[SpyEvent],
     ) -> None:
         heading = os.linesep.join(
@@ -70,7 +70,7 @@ class RedundantVerifyWarning(DecoyWarning):
 
     See the [RedundantVerifyWarning guide][] for more details.
 
-    [RedundantVerifyWarning guide]: ../usage/errors-and-warnings/#redundantverifywarning
+    [RedundantVerifyWarning guide]: usage/errors-and-warnings.md#redundantverifywarning
     """
 
     def __init__(self, rehearsal: VerifyRehearsal) -> None:
@@ -79,7 +79,7 @@ class RedundantVerifyWarning(DecoyWarning):
                 "The same rehearsal was used in both a `when` and a `verify`.",
                 "This is redundant and probably a misuse of the mock.",
                 f"\t{stringify_call(rehearsal)}",
-                "See https://mike.cousins.io/decoy/usage/errors-and-warnings/#redundantverifywarning",  # noqa: E501
+                "See https://michael.cousins.io/decoy/usage/errors-and-warnings/#redundantverifywarning",
             ]
         )
         super().__init__(message)
@@ -91,8 +91,17 @@ class IncorrectCallWarning(DecoyWarning):
 
     If a call to a Decoy mock is incorrect according to `inspect.signature`,
     this warning will be raised.
-
     See the [IncorrectCallWarning guide][] for more details.
 
-    [IncorrectCallWarning guide]: ../usage/errors-and-warnings/#incorrectcallwarning
+    [IncorrectCallWarning guide]: usage/errors-and-warnings.md#incorrectcallwarning
+    """
+
+
+class MissingSpecAttributeWarning(DecoyWarning):
+    """A warning raised if a Decoy mock with a spec is used with a missing attribute.
+
+    This will become an error in the next major version of Decoy.
+    See the [MissingSpecAttributeWarning guide][] for more details.
+
+    [MissingSpecAttributeWarning guide]: usage/errors-and-warnings.md#missingspecattributewarning
     """
